@@ -11,22 +11,25 @@ use warnings;
 
 use Object::Pluggable::Constants qw/ :ALL /;
 
-sub new { bless {}, shift }
+sub new { bless [], shift }
 
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
   
   $core->plugin_register( $self, 'SERVER',
-    [ 'public_cmd_reverse' ]  
+    'public_cmd_reverse'
   );
   
   $core->log->info("$VERSION loaded");
+
   return PLUGIN_EAT_NONE
 }
 
 sub Cobalt_unregister {
   my ($self, $core) = splice @_, 0, 2;
+
   $core->log->info("Unloaded");
+
   return PLUGIN_EAT_NONE
 }
 
@@ -40,6 +43,7 @@ sub Bot_public_cmd_reverse {
   my $reverse = scalar reverse $str;
 
   my $channel = $msg->channel;
+
   $core->send_event( 'send_message',
     $context,
     $channel,
